@@ -93,7 +93,7 @@ class RsvpP2mpEgressLsps(Base):
         """
         Returns
         -------
-        - obj(uhd_restpy.multivalue.Multivalue): Activate/Deactivate Configuration
+        - obj(uhd_restpy.multivalue.Multivalue): Activate/Deactivate Configuration.
         """
         from uhd_restpy.multivalue import Multivalue
         return Multivalue(self, self._get_attribute(self._SDM_ATT_MAP['Active']))
@@ -112,7 +112,7 @@ class RsvpP2mpEgressLsps(Base):
         """
         Returns
         -------
-        - str: Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offers more context
+        - str: Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
         """
         return self._get_attribute(self._SDM_ATT_MAP['DescriptiveName'])
 
@@ -393,7 +393,7 @@ class RsvpP2mpEgressLsps(Base):
 
         graftSubLsp(SessionIndices=list)
         --------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         graftSubLsp(SessionIndices=string)
         ----------------------------------
@@ -423,7 +423,7 @@ class RsvpP2mpEgressLsps(Base):
 
         pruneSubLsp(SessionIndices=list)
         --------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         pruneSubLsp(SessionIndices=string)
         ----------------------------------
@@ -453,7 +453,7 @@ class RsvpP2mpEgressLsps(Base):
 
         start(SessionIndices=list)
         --------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         start(SessionIndices=string)
         ----------------------------
@@ -483,7 +483,7 @@ class RsvpP2mpEgressLsps(Base):
 
         stop(SessionIndices=list)
         -------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         stop(SessionIndices=string)
         ---------------------------
